<?
/**
 * TRIBUNAL REGIONAL FEDERAL DA 4 REGIO
 *
 * 14/03/2017 - criado por pedro.cast
 *
 * Verso do Gerador de Cdigo: 1.40.0
 */

require_once dirname(__FILE__).'/../../../SEI.php';

class MdPetIntRelTipoRespRN extends InfraRN {

    public function __construct(){
        parent::__construct();
    }

    protected function inicializarObjInfraIBanco(){
        return BancoSEI::getInstance();
    }

    private function validarStrSinAtivo(MdPetIntRelTipoRespDTO $objMdPetIntRelTipoRespDTO, InfraException $objInfraException){
        if (InfraString::isBolVazia($objMdPetIntRelTipoRespDTO->getStrSinAtivo())){
            $objInfraException->adicionarValidacao('Sinalizador de Excluso Lgica no informado.');
        }else{
            if (!InfraUtil::isBolSinalizadorValido($objMdPetIntRelTipoRespDTO->getStrSinAtivo())){
                $objInfraException->adicionarValidacao('Sinalizador de Excluso Lgica invlido.');
            }
        }
    }

    private function validarNumIdMdPetIntimacao(MdPetIntRelTipoRespDTO $objMdPetIntRelTipoRespDTO, InfraException $objInfraException){
        if (InfraString::isBolVazia($objMdPetIntRelTipoRespDTO->getNumIdMdPetIntimacao())){
            $objInfraException->adicionarValidacao('Intimao no informada.');
        }
    }

    private function validarNumIdMdPetIntTipoResp(MdPetIntRelTipoRespDTO $objMdPetIntRelTipoRespDTO, InfraException $objInfraException){
        if (InfraString::isBolVazia($objMdPetIntRelTipoRespDTO->getNumIdMdPetIntTipoResp())){
            $objInfraException->adicionarValidacao('Tipo de Resposta no informado.');
        }
    }

    protected function cadastrarControlado(MdPetIntRelTipoRespDTO $objMdPetIntRelTipoRespDTO) {
        try{

            //Valida Permissao
            SessaoSEI::getInstance()->validarPermissao('md_pet_int_rel_tipo_resp_cadastrar');

            //Regras de Negocio
            $objInfraException = new InfraException();

            $this->validarStrSinAtivo($objMdPetIntRelTipoRespDTO, $objInfraException);
            $this->validarNumIdMdPetIntimacao($objMdPetIntRelTipoRespDTO, $objInfraException);
            $this->validarNumIdMdPetIntTipoResp($objMdPetIntRelTipoRespDTO, $objInfraException);

            $objInfraException->lancarValidacoes();

            $objMdPetIntRelTipoRespBD = new MdPetIntRelTipoRespBD($this->getObjInfraIBanco());
            $ret = $objMdPetIntRelTipoRespBD->cadastrar($objMdPetIntRelTipoRespDTO);

            //Auditoria

            return $ret;

        }catch(Exception $e){
            throw new InfraException('Erro cadastrando Tipo De Resposta da Intimao.',$e);
        }
    }

    protected function alterarControlado(MdPetIntRelTipoRespDTO $objMdPetIntRelTipoRespDTO){
        try {

            //Valida Permissao
            SessaoSEI::getInstance()->validarPermissao('md_pet_int_rel_tipo_resp_alterar');

            //Regras de Negocio
            $objInfraException = new InfraException();

            if ($objMdPetIntRelTipoRespDTO->isSetStrSinAtivo()){
                $this->validarStrSinAtivo($objMdPetIntRelTipoRespDTO, $objInfraException);
            }
            if ($objMdPetIntRelTipoRespDTO->isSetNumIdMdPetIntimacao()){
                $this->validarNumIdMdPetIntimacao($objMdPetIntRelTipoRespDTO, $objInfraException);
            }
            if ($objMdPetIntRelTipoRespDTO->isSetNumIdMdPetIntTipoResp()){
                $this->validarNumIdMdPetIntTipoResp($objMdPetIntRelTipoRespDTO, $objInfraException);
            }

            $objInfraException->lancarValidacoes();

            $objMdPetIntRelTipoRespBD = new MdPetIntRelTipoRespBD($this->getObjInfraIBanco());
            $objMdPetIntRelTipoRespBD->alterar($objMdPetIntRelTipoRespDTO);

            //Auditoria

        }catch(Exception $e){
            throw new InfraException('Erro alterando Tipo De Resposta da Intimao.',$e);
        }
    }

    protected function excluirControlado($arrObjMdPetIntRelTipoRespDTO){
        try {

            //Valida Permissao
            SessaoSEI::getInstance()->validarPermissao('md_pet_int_rel_tipo_resp_excluir');

            //Regras de Negocio
            //$objInfraException = new InfraException();

            //$objInfraException->lancarValidacoes();

            $objMdPetIntRelTipoRespBD = new MdPetIntRelTipoRespBD($this->getObjInfraIBanco());
            for($i=0;$i<count($arrObjMdPetIntRelTipoRespDTO);$i++){
                $objMdPetIntRelTipoRespBD->excluir($arrObjMdPetIntRelTipoRespDTO[$i]);
            }

            //Auditoria

        }catch(Exception $e){
            throw new InfraException('Erro excluindo Tipo De Resposta da Intimao.',$e);
        }
    }

    protected function consultarConectado(MdPetIntRelTipoRespDTO $objMdPetIntRelTipoRespDTO){
        try {

            //Valida Permissao
            SessaoSEI::getInstance()->validarPermissao('md_pet_int_rel_tipo_resp_consultar');

            //Regras de Negocio
            //$objInfraException = new InfraException();

            //$objInfraException->lancarValidacoes();

            $objMdPetIntRelTipoRespBD = new MdPetIntRelTipoRespBD($this->getObjInfraIBanco());
            $ret = $objMdPetIntRelTipoRespBD->consultar($objMdPetIntRelTipoRespDTO);

            //Auditoria

            return $ret;
        }catch(Exception $e){
            throw new InfraException('Erro consultando Tipo De Resposta da Intimao.',$e);
        }
    }

    protected function listarConectado(MdPetIntRelTipoRespDTO $objMdPetIntRelTipoRespDTO) {
        try {

            //Valida Permissao
            SessaoSEI::getInstance()->validarPermissao('md_pet_int_rel_tipo_resp_listar');

            //Regras de Negocio
            //$objInfraException = new InfraException();

            //$objInfraException->lancarValidacoes();

            $objMdPetIntRelTipoRespBD = new MdPetIntRelTipoRespBD($this->getObjInfraIBanco());
            $ret = $objMdPetIntRelTipoRespBD->listar($objMdPetIntRelTipoRespDTO);

            //Auditoria

            return $ret;

        }catch(Exception $e){
            throw new InfraException('Erro listando Tipos de Resposta da Intimao.',$e);
        }
    }

    protected function contarConectado(MdPetIntRelTipoRespDTO $objMdPetIntRelTipoRespDTO){
        try {

            //Valida Permissao
            SessaoSEI::getInstance()->validarPermissao('md_pet_int_rel_tipo_resp_listar');

            //Regras de Negocio
            //$objInfraException = new InfraException();

            //$objInfraException->lancarValidacoes();

            $objMdPetIntRelTipoRespBD = new MdPetIntRelTipoRespBD($this->getObjInfraIBanco());
            $ret = $objMdPetIntRelTipoRespBD->contar($objMdPetIntRelTipoRespDTO);

            //Auditoria

            return $ret;
        }catch(Exception $e){
            throw new InfraException('Erro contando Tipos de Resposta da Intimao.',$e);
        }
    }

    protected function desativarControlado($arrObjMdPetIntRelTipoRespDTO){
        try {

            //Valida Permissao
            SessaoSEI::getInstance()->validarPermissao('md_pet_int_rel_tipo_resp_desativar');

            //Regras de Negocio
            //$objInfraException = new InfraException();

            //$objInfraException->lancarValidacoes();

            $objMdPetIntRelTipoRespBD = new MdPetIntRelTipoRespBD($this->getObjInfraIBanco());
            for($i=0;$i<count($arrObjMdPetIntRelTipoRespDTO);$i++){
                $objMdPetIntRelTipoRespBD->desativar($arrObjMdPetIntRelTipoRespDTO[$i]);
            }

            //Auditoria

        }catch(Exception $e){
            throw new InfraException('Erro desativando Tipo De Resposta da Intimao.',$e);
        }
    }

    protected function reativarControlado($arrObjMdPetIntRelTipoRespDTO){
        try {

            //Valida Permissao
            SessaoSEI::getInstance()->validarPermissao('md_pet_int_rel_tipo_resp_reativar');

            //Regras de Negocio
            //$objInfraException = new InfraException();

            //$objInfraException->lancarValidacoes();

            $objMdPetIntRelTipoRespBD = new MdPetIntRelTipoRespBD($this->getObjInfraIBanco());
            for($i=0;$i<count($arrObjMdPetIntRelTipoRespDTO);$i++){
                $objMdPetIntRelTipoRespBD->reativar($arrObjMdPetIntRelTipoRespDTO[$i]);
            }

            //Auditoria

        }catch(Exception $e){
            throw new InfraException('Erro reativando Tipo De Resposta da Intimao.',$e);
        }
    }

    protected function bloquearControlado(MdPetIntRelTipoRespDTO $objMdPetIntRelTipoRespDTO){
        try {

            //Valida Permissao
            SessaoSEI::getInstance()->validarPermissao('md_pet_int_rel_tipo_resp_consultar');

            //Regras de Negocio
            //$objInfraException = new InfraException();

            //$objInfraException->lancarValidacoes();

            $objMdPetIntRelTipoRespBD = new MdPetIntRelTipoRespBD($this->getObjInfraIBanco());
            $ret = $objMdPetIntRelTipoRespBD->bloquear($objMdPetIntRelTipoRespDTO);

            //Auditoria

            return $ret;
        }catch(Exception $e){
            throw new InfraException('Erro bloqueando Tipo De Resposta da Intimao.',$e);
        }
    }

    protected function listarTipoRespostaConectado($params)
    {
        $numIdMdPetIntimacao   = $params[0];
        $numIdMdPetIntRelDest  = $params[1];

        $objMdPetIntRelTipoRespDTO = new MdPetIntRelTipoRespDTO();
        $objMdPetIntRelTipoRespDTO->retTodos(true);
        $objMdPetIntRelTipoRespDTO->setNumIdMdPetIntimacao($numIdMdPetIntimacao);

        if (!is_null($numIdMdPetIntRelDest)){
            $objMdPetIntRelTipoRespDTO->setNumIdMdPetIntRelDest($numIdMdPetIntRelDest);
        }
        $objMdPetIntRelTipoRespDTO->setStrSinAtivo('S');
        return $this->listar($objMdPetIntRelTipoRespDTO);
    }


    protected function validarExclusaoTipoRespostaConectado($idTipoResposta)
    {
        $objMdPetIntRelTpRespDTO = new MdPetIntRelTipoRespDTO();
        $objMdPetIntRelTpRespRN = new MdPetIntRelTipoRespRN();

        $objMdPetIntRelTpRespDTO->setNumIdMdPetIntTipoResp($idTipoResposta);
        $objMdPetIntRelTpRespDTO->retNumIdMdPetIntTipoResp();

        $existeResp = $objMdPetIntRelTpRespRN->contar($objMdPetIntRelTpRespDTO) > 0 ? 1 : 0;

        return $existeResp;
    }


}
?>